@@ -1,5 +1,5 @@
 tm_tag_score <- function(x, tags, FUN) UseMethod("tm_tag_score", x)
-tm_tag_score.numeric <- function(x, tags, FUN)
+tm_tag_score.term_frequency <- function(x, tags, FUN)
     FUN(x[match(tags, names(x))])
 tm_tag_score.PlainTextDocument <- function(x, tags, FUN = function(x) sum(x, na.rm = TRUE))
     tm_tag_score(termFreq(x, control = list(removePunctuation = TRUE)), tags, FUN)
